package com.ygtx.gxt.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ygtx.gxt.mapper.GxtFanInspectionScoreMapper;
import com.ygtx.gxt.domain.GxtFanInspectionScore;
import com.ygtx.gxt.service.IGxtFanInspectionScoreService;

/**
 * 风机类型检查分值Service业务层处理
 * 
 * @author ruoyi
 * @date 2025-11-06
 */
@Service
public class GxtFanInspectionScoreServiceImpl implements IGxtFanInspectionScoreService 
{
    @Autowired
    private GxtFanInspectionScoreMapper gxtFanInspectionScoreMapper;

    /**
     * 查询风机类型检查分值
     * 
     * @param id 风机类型检查分值主键
     * @return 风机类型检查分值
     */
    @Override
    public GxtFanInspectionScore selectGxtFanInspectionScoreById(Long id)
    {
        return gxtFanInspectionScoreMapper.selectGxtFanInspectionScoreById(id);
    }

    /**
     * 查询风机类型检查分值列表
     * 
     * @param gxtFanInspectionScore 风机类型检查分值
     * @return 风机类型检查分值
     */
    @Override
    public List<GxtFanInspectionScore> selectGxtFanInspectionScoreList(GxtFanInspectionScore gxtFanInspectionScore)
    {
        return gxtFanInspectionScoreMapper.selectGxtFanInspectionScoreList(gxtFanInspectionScore);
    }

    /**
     * 根据风机类型查询风机类型检查分值列表
     * 
     * @param fanType 风机类型
     * @return 风机类型检查分值集合
     */
    @Override
    public List<GxtFanInspectionScore> selectGxtFanInspectionScoreByFanType(String fanType)
    {
        return gxtFanInspectionScoreMapper.selectGxtFanInspectionScoreByFanType(fanType);
    }

    /**
     * 新增风机类型检查分值
     * 
     * @param gxtFanInspectionScore 风机类型检查分值
     * @return 结果
     */
    @Override
    public int insertGxtFanInspectionScore(GxtFanInspectionScore gxtFanInspectionScore)
    {
        return gxtFanInspectionScoreMapper.insertGxtFanInspectionScore(gxtFanInspectionScore);
    }

    /**
     * 修改风机类型检查分值
     * 
     * @param gxtFanInspectionScore 风机类型检查分值
     * @return 结果
     */
    @Override
    public int updateGxtFanInspectionScore(GxtFanInspectionScore gxtFanInspectionScore)
    {
        return gxtFanInspectionScoreMapper.updateGxtFanInspectionScore(gxtFanInspectionScore);
    }

    /**
     * 批量删除风机类型检查分值
     * 
     * @param ids 需要删除的风机类型检查分值主键
     * @return 结果
     */
    @Override
    public int deleteGxtFanInspectionScoreByIds(Long[] ids)
    {
        return gxtFanInspectionScoreMapper.deleteGxtFanInspectionScoreByIds(ids);
    }

    /**
     * 删除风机类型检查分值信息
     * 
     * @param id 风机类型检查分值主键
     * @return 结果
     */
    @Override
    public int deleteGxtFanInspectionScoreById(Long id)
    {
        return gxtFanInspectionScoreMapper.deleteGxtFanInspectionScoreById(id);
    }
}